char *s = N_("Global Appearance Setup");
char *s = N_("Look and Feel");
